# doreah

[![](https://img.shields.io/pypi/v/doreah?style=for-the-badge)](https://pypi.org/project/doreah/)
[![](https://img.shields.io/pypi/dm/doreah?style=for-the-badge)](https://pypi.org/project/doreah/)
[![](https://img.shields.io/github/stars/krateng/doreah?style=for-the-badge&color=purple)](https://github.com/krateng/doreah/stargazers)
[![](https://img.shields.io/pypi/l/doreah?style=for-the-badge)](https://github.com/krateng/doreah/blob/master/LICENSE)

A collection of useful tools used in my Python projects. Since it's intended for personal use, I can not offer any guarantee for API consistency, backwards compatibility or similar.

Install with `pip install doreah`.


[Documentation](https://doreah.readthedocs.io)
